Intel® Threading Building Blocks. Convex_hull sample

# Intel® Threading Building Blocks.
Convex_hull sample

Parallel version of convex hull algorithm (quick hull).

System Requirements

For the most up to date system requirements, see the release notes.

Files

convex_hull_sample.cpp
  Source code for parallel version of the example which uses parallel_reduce, parallel_for and concurrent_vector.
convex_hull_bench.cpp
  Source code for the version of the example that compares serial and parallel buffered and unbuffered implementations.
convex_hull.h
  Include file for the example.
Makefile
  Makefile for building the example.

Directories

msvs
  Contains Microsoft* Visual Studio* workspace for building and running the example (Windows* systems only).
xcode
  Contains Xcode* IDE workspace for building and running the example (macOS* systems only).

For information about the minimum supported version of IDE, see release notes.

Build instructions

General build directions can be found here.

Usage

`convex_hull_sample [S] [M[:N]] [-v]`
  S is the number of points (problem size). M:N are a range of numbers of threads to be used. Use the -v option to turn on verbose output.
To run a short version of this example, e.g., for use with Intel® Threading Tools:
  Build a debug version of the example (see the build instructions).
  Run it with a small problem size and the desired number of threads, e.g., `convex_hull_sample 500000 4`.

Up to parent directory

Legal Information

Intel and the Intel logo are trademarks of Intel Corporation in the U.S. and/or other countries.
* Other names and brands may be claimed as the property of others.
© 2018, Intel Corporation